import _plotly_utils.basevalidators


class BoxmodeValidator(_plotly_utils.basevalidators.EnumeratedValidator):
    def __init__(self, plotly_name="boxmode", parent_name="layout", **kwargs):
        super(BoxmodeValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "calc"),
            values=kwargs.pop("values", ["group", "overlay"]),
            **kwargs,
        )



import _plotly_utils.basevalidators


class FillcolorValidator(_plotly_utils.basevalidators.ColorValidator):
    def __init__(self, plotly_name="fillcolor", parent_name="contourcarpet", **kwargs):
        super(FillcolorValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "calc"),
            colorscale_path=kwargs.pop("colorscale_path", "contourcarpet.colorscale"),
            **kwargs,
        )



print("import: 'jupyterlab_plotly'")
import jupyterlab_plotly

print("import: 'plotly'")
import plotly

print("import: 'plotly.offline'")
import plotly.offline

print("import: 'plotly.io'")
import plotly.io

print("import: 'plotly.data'")
import plotly.data

print("import: 'plotly.colors'")
import plotly.colors

print("import: 'plotly.graph_objects'")
import plotly.graph_objects

print("import: '_plotly_utils'")
import _plotly_utils

print("import: '_plotly_utils.colors'")
import _plotly_utils.colors

print("import: '_plotly_future_'")
import _plotly_future_

print("import: 'plotly.graph_objs.bar'")
import plotly.graph_objs.bar

print("import: 'plotly.graph_objs.barpolar'")
import plotly.graph_objs.barpolar

print("import: 'plotly.graph_objs.box'")
import plotly.graph_objs.box

print("import: 'plotly.graph_objs.candlestick'")
import plotly.graph_objs.candlestick

print("import: 'plotly.graph_objs.carpet'")
import plotly.graph_objs.carpet

print("import: 'plotly.graph_objs.choropleth'")
import plotly.graph_objs.choropleth

print("import: 'plotly.graph_objs.choroplethmapbox'")
import plotly.graph_objs.choroplethmapbox

print("import: 'plotly.graph_objs.cone'")
import plotly.graph_objs.cone

print("import: 'plotly.graph_objs.contour'")
import plotly.graph_objs.contour

print("import: 'plotly.graph_objs.contourcarpet'")
import plotly.graph_objs.contourcarpet

print("import: 'plotly.graph_objs.densitymapbox'")
import plotly.graph_objs.densitymapbox

print("import: 'plotly.graph_objs.funnel'")
import plotly.graph_objs.funnel

print("import: 'plotly.graph_objs.funnelarea'")
import plotly.graph_objs.funnelarea

print("import: 'plotly.graph_objs.heatmap'")
import plotly.graph_objs.heatmap

print("import: 'plotly.graph_objs.heatmapgl'")
import plotly.graph_objs.heatmapgl

print("import: 'plotly.graph_objs.histogram'")
import plotly.graph_objs.histogram

print("import: 'plotly.graph_objs.histogram2d'")
import plotly.graph_objs.histogram2d

print("import: 'plotly.graph_objs.histogram2dcontour'")
import plotly.graph_objs.histogram2dcontour

print("import: 'plotly.graph_objs.icicle'")
import plotly.graph_objs.icicle

print("import: 'plotly.graph_objs.image'")
import plotly.graph_objs.image

print("import: 'plotly.graph_objs.indicator'")
import plotly.graph_objs.indicator

print("import: 'plotly.graph_objs.isosurface'")
import plotly.graph_objs.isosurface

print("import: 'plotly.graph_objs.layout'")
import plotly.graph_objs.layout

print("import: 'plotly.graph_objs.mesh3d'")
import plotly.graph_objs.mesh3d

print("import: 'plotly.graph_objs.ohlc'")
import plotly.graph_objs.ohlc

print("import: 'plotly.graph_objs.parcats'")
import plotly.graph_objs.parcats

print("import: 'plotly.graph_objs.parcoords'")
import plotly.graph_objs.parcoords

print("import: 'plotly.graph_objs.pie'")
import plotly.graph_objs.pie

print("import: 'plotly.graph_objs.pointcloud'")
import plotly.graph_objs.pointcloud

print("import: 'plotly.graph_objs.sankey'")
import plotly.graph_objs.sankey

print("import: 'plotly.graph_objs.scatter'")
import plotly.graph_objs.scatter

print("import: 'plotly.graph_objs.scatter3d'")
import plotly.graph_objs.scatter3d

print("import: 'plotly.graph_objs.scattercarpet'")
import plotly.graph_objs.scattercarpet

print("import: 'plotly.graph_objs.scattergeo'")
import plotly.graph_objs.scattergeo

print("import: 'plotly.graph_objs.scattergl'")
import plotly.graph_objs.scattergl

print("import: 'plotly.graph_objs.scattermapbox'")
import plotly.graph_objs.scattermapbox

print("import: 'plotly.graph_objs.scatterpolar'")
import plotly.graph_objs.scatterpolar

print("import: 'plotly.graph_objs.scatterpolargl'")
import plotly.graph_objs.scatterpolargl

print("import: 'plotly.graph_objs.scatterternary'")
import plotly.graph_objs.scatterternary

print("import: 'plotly.graph_objs.splom'")
import plotly.graph_objs.splom

print("import: 'plotly.graph_objs.streamtube'")
import plotly.graph_objs.streamtube

print("import: 'plotly.graph_objs.sunburst'")
import plotly.graph_objs.sunburst

print("import: 'plotly.graph_objs.surface'")
import plotly.graph_objs.surface

print("import: 'plotly.graph_objs.table'")
import plotly.graph_objs.table

print("import: 'plotly.graph_objs.treemap'")
import plotly.graph_objs.treemap

print("import: 'plotly.graph_objs.violin'")
import plotly.graph_objs.violin

print("import: 'plotly.graph_objs.volume'")
import plotly.graph_objs.volume

print("import: 'plotly.graph_objs.waterfall'")
import plotly.graph_objs.waterfall

print("import: 'plotly.validators'")
import plotly.validators

print("import: 'plotly.validators.bar'")
import plotly.validators.bar

print("import: 'plotly.validators.barpolar'")
import plotly.validators.barpolar

print("import: 'plotly.validators.box'")
import plotly.validators.box

print("import: 'plotly.validators.candlestick'")
import plotly.validators.candlestick

print("import: 'plotly.validators.carpet'")
import plotly.validators.carpet

print("import: 'plotly.validators.choropleth'")
import plotly.validators.choropleth

print("import: 'plotly.validators.choroplethmapbox'")
import plotly.validators.choroplethmapbox

print("import: 'plotly.validators.cone'")
import plotly.validators.cone

print("import: 'plotly.validators.contour'")
import plotly.validators.contour

print("import: 'plotly.validators.contourcarpet'")
import plotly.validators.contourcarpet

print("import: 'plotly.validators.densitymapbox'")
import plotly.validators.densitymapbox

print("import: 'plotly.validators.frame'")
import plotly.validators.frame

print("import: 'plotly.validators.funnel'")
import plotly.validators.funnel

print("import: 'plotly.validators.funnelarea'")
import plotly.validators.funnelarea

print("import: 'plotly.validators.heatmap'")
import plotly.validators.heatmap

print("import: 'plotly.validators.heatmapgl'")
import plotly.validators.heatmapgl

print("import: 'plotly.validators.histogram'")
import plotly.validators.histogram

print("import: 'plotly.validators.histogram2d'")
import plotly.validators.histogram2d

print("import: 'plotly.validators.histogram2dcontour'")
import plotly.validators.histogram2dcontour

print("import: 'plotly.validators.icicle'")
import plotly.validators.icicle

print("import: 'plotly.validators.image'")
import plotly.validators.image

print("import: 'plotly.validators.indicator'")
import plotly.validators.indicator

print("import: 'plotly.validators.isosurface'")
import plotly.validators.isosurface

print("import: 'plotly.validators.layout'")
import plotly.validators.layout

print("import: 'plotly.validators.mesh3d'")
import plotly.validators.mesh3d

print("import: 'plotly.validators.ohlc'")
import plotly.validators.ohlc

print("import: 'plotly.validators.parcats'")
import plotly.validators.parcats

print("import: 'plotly.validators.parcoords'")
import plotly.validators.parcoords

print("import: 'plotly.validators.pie'")
import plotly.validators.pie

print("import: 'plotly.validators.pointcloud'")
import plotly.validators.pointcloud

print("import: 'plotly.validators.sankey'")
import plotly.validators.sankey

print("import: 'plotly.validators.scatter'")
import plotly.validators.scatter

print("import: 'plotly.validators.scatter3d'")
import plotly.validators.scatter3d

print("import: 'plotly.validators.scattercarpet'")
import plotly.validators.scattercarpet

print("import: 'plotly.validators.scattergeo'")
import plotly.validators.scattergeo

print("import: 'plotly.validators.scattergl'")
import plotly.validators.scattergl

print("import: 'plotly.validators.scattermapbox'")
import plotly.validators.scattermapbox

print("import: 'plotly.validators.scatterpolar'")
import plotly.validators.scatterpolar

print("import: 'plotly.validators.scatterpolargl'")
import plotly.validators.scatterpolargl

print("import: 'plotly.validators.scatterternary'")
import plotly.validators.scatterternary

print("import: 'plotly.validators.splom'")
import plotly.validators.splom

print("import: 'plotly.validators.streamtube'")
import plotly.validators.streamtube

print("import: 'plotly.validators.sunburst'")
import plotly.validators.sunburst

print("import: 'plotly.validators.surface'")
import plotly.validators.surface

print("import: 'plotly.validators.table'")
import plotly.validators.table

print("import: 'plotly.validators.treemap'")
import plotly.validators.treemap

print("import: 'plotly.validators.violin'")
import plotly.validators.violin

print("import: 'plotly.validators.volume'")
import plotly.validators.volume

print("import: 'plotly.validators.waterfall'")
import plotly.validators.waterfall




import _plotly_utils.basevalidators


class ZValidator(_plotly_utils.basevalidators.NumberValidator):
    def __init__(self, plotly_name="z", parent_name="surface.lightposition", **kwargs):
        super(ZValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "calc"),
            max=kwargs.pop("max", 100000),
            min=kwargs.pop("min", -100000),
            **kwargs,
        )



import _plotly_utils.basevalidators


class NameValidator(_plotly_utils.basevalidators.StringValidator):
    def __init__(
        self,
        plotly_name="name",
        parent_name="choroplethmapbox.colorbar.tickformatstop",
        **kwargs,
    ):
        super(NameValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "colorbars"),
            **kwargs,
        )



import _plotly_utils.basevalidators


class TValidator(_plotly_utils.basevalidators.NumberValidator):
    def __init__(self, plotly_name="t", parent_name="layout.updatemenu.pad", **kwargs):
        super(TValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "arraydraw"),
            **kwargs,
        )



import _plotly_utils.basevalidators


class VisibleValidator(_plotly_utils.basevalidators.BooleanValidator):
    def __init__(
        self, plotly_name="visible", parent_name="layout.annotation", **kwargs
    ):
        super(VisibleValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "calc+arraydraw"),
            **kwargs,
        )



"""Built-in datasets for demonstration, educational and test purposes.
"""

from plotly.data import *

__all__ = [
    "carshare",
    "election",
    "election_geojson",
    "experiment",
    "gapminder",
    "iris",
    "medals_wide",
    "medals_long",
    "stocks",
    "tips",
    "wind",
]



import _plotly_utils.basevalidators


class HovertextsrcValidator(_plotly_utils.basevalidators.SrcValidator):
    def __init__(self, plotly_name="hovertextsrc", parent_name="treemap", **kwargs):
        super(HovertextsrcValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "none"),
            **kwargs,
        )



import _plotly_utils.basevalidators


class TickprefixValidator(_plotly_utils.basevalidators.StringValidator):
    def __init__(self, plotly_name="tickprefix", parent_name="carpet.aaxis", **kwargs):
        super(TickprefixValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            edit_type=kwargs.pop("edit_type", "calc"),
            **kwargs,
        )
